"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.calcDurationSec = exports.createRecorder = void 0;

/**
 * Gets event history of `command` registered in `historyMap.
 * If absent, creates new one and returns it.
 */
const getHistory = function (command) {
  const { historyMap } = this;
  const history = historyMap.get(command);
  if (history) return history;
  const newHistory = [];
  historyMap.set(command, newHistory);
  return newHistory;
};

/** `record()` method of `Recorder`. */
const record = function (command, event) {
  const timestamp = new Date().getTime();
  this.getHistory(command).push({ event, timestamp });
};

/** Creates a new `Recorder` object. */
const createRecorder = () => ({
  historyMap: new Map(),
  record,
  getHistory,
});
exports.createRecorder = createRecorder;
const calcDurationSec = (history) => {
  const len = history.length;
  if (!len) return 0;
  const first = history[0].timestamp;
  const last = history[len - 1].timestamp;
  return (last - first) / 1000;
};
exports.calcDurationSec = calcDurationSec;
