"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.depthFirstSearch = void 0;

/**
 * Runs `callback` for `topCommand` and all of its descendants in a
 * depth-first order, until it finds any `Command` that matches the predicate.
 */
const depthFirstSearch = (topCommand, callback, currentDepth = 0) => {
  const found = callback(topCommand, currentDepth);
  if (found) return topCommand;
  if (!topCommand.children) return undefined;
  const childDepth = currentDepth + 1;
  for (const child of topCommand.children) {
    const foundCommand = exports.depthFirstSearch(child, callback, childDepth);
    if (foundCommand) return foundCommand;
  }
  return undefined;
};
exports.depthFirstSearch = depthFirstSearch;
